"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Customers = void 0;
const baseResource_1 = require("./baseResource");
class Customers extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/customers", config);
    }
    async update(request) {
        return this.httpPatch(`/${request.customerId}`, { data: request.data });
    }
    async get(customerId) {
        return this.httpGet(`/${customerId}`);
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.query) && { "filter[query]": params.query }),
            ...((params === null || params === void 0 ? void 0 : params.email) && { "filter[email]": params.email }),
            ...((params === null || params === void 0 ? void 0 : params.tags) && { "filter[tags]": params.tags }),
            "sort": (params === null || params === void 0 ? void 0 : params.sort) ? params.sort : "-createdAt"
        };
        if (params === null || params === void 0 ? void 0 : params.status)
            params.status.forEach((s, idx) => {
                parameters[`filter[status][${idx}]`] = s;
            });
        return this.httpGet("", { params: parameters });
    }
    async archiveCustomer(request) {
        return this.httpPost(`/${request.customerId}/archive`, { data: request.data });
    }
    async addAuthorizedUsers(request) {
        return this.httpPost(`/${request.customerId}/authorized-users`, { data: request.data });
    }
    async removeAuthorizedUsers(request) {
        return this.httpDelete(`/${request.customerId}/authorized-users`, { data: request.data });
    }
}
exports.Customers = Customers;
