"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const unit_1 = require("../unit");
const dotenv_1 = __importDefault(require("dotenv"));
const testHelpers_1 = require("./testHelpers");
const helpers_1 = require("../helpers");
dotenv_1.default.config();
const unit = new unit_1.Unit(process.env.UNIT_TOKEN || "test", process.env.UNIT_API_URL || "test");
const customersId = [];
describe("Customers List", () => {
    test("Get Customers List", async () => {
        const res = await unit.customers.list();
        res.data.forEach(element => {
            expect(element.type === "businessCustomer" || element.type === "individualCustomer").toBeTruthy();
            customersId.push(element.id);
        });
    });
});
describe("Get Customer Test", () => {
    test("get each customer", async () => {
        customersId.forEach(async (id) => {
            const res = await unit.customers.get(id);
            expect(res.data.type === "businessCustomer" || res.data.type === "individualCustomer").toBeTruthy();
        });
    });
});
describe("Authorized Users for Customer Test", () => {
    test("add authorized users", async () => {
        const customerId = await (0, testHelpers_1.createIndividualCustomer)(unit);
        const a_user = (0, helpers_1.createAuthorizedUser)((0, helpers_1.createFullName)("Erlich", "Backman"), "erlich@piedpiper.com", (0, helpers_1.createPhone)("1", "1234567890"));
        const req = (0, helpers_1.createAddAuthorizedUsersRequest)(customerId, [a_user]);
        const res = await unit.customers.addAuthorizedUsers(req);
        expect(res.data.type === "individualCustomer").toBeTruthy();
        expect(res.data.attributes.authorizedUsers[0].fullName.first).toBe("Erlich");
    });
    test("add and remove authorized users", async () => {
        const customerId = await (0, testHelpers_1.createIndividualCustomer)(unit);
        const a_user = (0, helpers_1.createAuthorizedUser)((0, helpers_1.createFullName)("Erlich", "Backman"), "erlich@piedpiper.com", (0, helpers_1.createPhone)("1", "1234567890"));
        const req = (0, helpers_1.createAddAuthorizedUsersRequest)(customerId, [a_user]);
        const res = await unit.customers.addAuthorizedUsers(req);
        expect(res.data.type === "individualCustomer").toBeTruthy();
        expect(res.data.attributes.authorizedUsers[0].fullName.first).toBe("Erlich");
        const deleteReq = (0, helpers_1.createRemoveAuthorizedUsersRequest)(customerId, [a_user.email]);
        const deleteRes = await unit.customers.removeAuthorizedUsers(deleteReq);
        expect(deleteRes.data.type === "individualCustomer").toBeTruthy();
        expect(deleteRes.data.attributes.authorizedUsers).toStrictEqual([]);
    });
});
